This is the rust-rocket crate. It is designed to work as a client library for GNU Rocket.
Re-exports
pub use client::RocketClient;pub use player::RocketPlayer;
Modules
- This module contains the main client code, including the
RocketClienttype. - This module contains anything related to interpolation.
- This module contains a barebones player.
- This module contains
KeyandTracktypes.