pub enum Error {
Connect(Error),
Handshake(Error),
HandshakeGreetingMismatch([u8; 12]),
SetNonblocking(Error),
IOError(Error),
}Expand description
The Error Type. This is the main error type.
Variants
Connect(Error)
Failure to connect to a rocket tracker. This can happen if the tracker is not running, the address isn’t correct or other network-related reasons.
Handshake(Error)
Failure to transmit or receive greetings with the tracker
HandshakeGreetingMismatch([u8; 12])
Handshake was performed but the the received greeting wasn’t correct
SetNonblocking(Error)
Error from TcpStream::set_nonblocking
IOError(Error)
Network IO error during operation