Struct rust_rocket::track::Track [] [src]

pub struct Track { /* fields omitted */ }

The Track Type. This is a collection of Keys with a name.

Methods

impl Track
[src]

[src]

Construct a new Track with a name.

[src]

Get the name of the track.

[src]

Insert or update a key on a track.

[src]

Delete a key from a track.

If a key does not exist this will do nothing.

[src]

Get a value based on a row.

The row can be between two integers. This will perform the required interpolation.