Struct rust_rocket::track::Track
[−]
[src]
pub struct Track { /* fields omitted */ }The Track Type. This is a collection of Keys with a name.
Methods
impl Track[src]
pub fn new<S: Into<String>>(name: S) -> Track[src]
Construct a new Track with a name.
pub fn get_name(&self) -> &str[src]
Get the name of the track.
pub fn set_key(&mut self, key: Key)[src]
Insert or update a key on a track.
pub fn delete_key(&mut self, row: u32)[src]
Delete a key from a track.
If a key does not exist this will do nothing.
pub fn get_value(&self, row: f32) -> f32[src]
Get a value based on a row.
The row can be between two integers. This will perform the required interpolation.